@@ -1,6 +1,7 @@
 """
 Utility methods for brew
 """
+import os
 from sprinter.lib import extract_targz
 
 HOMEBREW_URL = "https://github.com/mxcl/homebrew/tarball/master"
@@ -8,9 +9,6 @@ HOMEBREW_URL = "https://github.com/mxcl/homebrew/tarball/master"
 
 def install_brew(target_path):
     """ Install brew to the target path """
+    if not os.path.exists(target_path):
+        os.makedirs(target_path)
     extract_targz(HOMEBREW_URL, target_path, remove_common_prefix=True)
-
-
-def install_brew_package(package, brew_executable="brew"):
-    """ Install a brew package """
-    "%s install %s" % (brew_executable, package)
