@@ -7,6 +7,10 @@ class SprinterException(Exception):
     """ For generic sprinter exceptions """
 
 
+class FormulaException(Exception):
+    """ For a generic exception with a formula """
+
+
 class CommandMissingException(Exception):
     """ Return if command doesn't exist """
 
