@@ -8,6 +8,7 @@ import sys
 from optparse import OptionParser
 
 from sprinter import lib
+from sprinter.core import PHASE
 from sprinter.environment import Environment
 from sprinter.manifest import Manifest
 from sprinter.directory import Directory
@@ -15,13 +16,13 @@ from sprinter.exceptions import SprinterException, BadCredentialsException
 
 env = None
 
-description = \
-"""
+description = """
 Install an environment as specified in a sprinter config file
 """
 
-VALID_COMMANDS = ["install", "update", "remove", "deactivate", "activate",
-                  "environments", "reconfigure", "validate"]
+VALID_COMMANDS = ["install", "update", "remove",
+                  "deactivate", "activate", "validate",
+                  "environments"]
 
 parser = OptionParser(description=description)
 # parser = argparse.ArgumentParser(description=description)
@@ -37,18 +38,17 @@ parser.add_option('--auth', dest='auth', action='store_true',
 parser.add_option('--password', dest='password', default=None,
                   help="Password if the url requires authentication")
 parser.add_option('-v', dest='verbose', action='store_true', help="Make output verbose")
-parser.add_option('--reconfigure', dest='reconfigure', default=False,
+parser.add_option('--reconfigure', dest='reconfigure', default=False, action="store_true",
                   help="if true, a sprinter update will reconfigure the existing environment specified")
 # not implemented yet
+"""
 parser.add_option('--sandboxbrew', dest='sandbox_brew', default=False,
                   help="if true, sandbox a brew installation, alternatively, " +
                   "false will disable brew sandboxes for configuration that request it.")
 parser.add_option('--sandboxaptget', dest='sandbox_aptget', default=False,
                   help="if true, sandbox an apt-get installation, alternatively, " +
                   "false will disable apt-get sandboxes for configuration that request it.")
-parser.add_option('--virtualenv', dest='virtualenv', default=False,
-                  help="if true, will virtualenv sprinter and install eggs relative to it, " +
-                  "false will disable apt-get sandboxes for configuration that request it.")
+"""
 
 
 def signal_handler(signal, frame):
@@ -87,10 +87,10 @@ def parse_args(argv, Environment=Environment):
     try:
         if command == "install":
             def handle_install_shutdown(signal, frame):
-                if env.last_phase == "install":
+                if env.phase == PHASE.INSTALL:
                     print "Removing install..."
                     env.directory.remove()
-                    env.clear_environment_rc()
+                    env.clear_all()
                 signal_handler(signal, frame)
             signal.signal(signal.SIGINT, handle_install_shutdown)
             if options.username or options.auth:
@@ -132,16 +132,11 @@ def parse_args(argv, Environment=Environment):
     except BadCredentialsException, e:
         raise e
     except Exception, e:
-        if not isinstance(e, SprinterException):
-            env.logger.exception("An exception occurred!")
-        else:
-            env.logger.error(str(e))
+        env.log_error(str(e))
         env.logger.info("failed! Writing debug output to /tmp/sprinter.log")
         env.write_debug_log("/tmp/sprinter.log")
         if env.message_failure():
-            env.logger.info(env.message_failure)
-        if not isinstance(e, SprinterException):
-            raise e
+            env.logger.info(env.message_failure())
 
 
 def parse_domain(url):
