@@ -23,47 +23,51 @@ from base64 import b64encode
 from getpass import getpass
 from subprocess import PIPE, STDOUT
 
-from sprinter.formulabase import FormulaBase
 from sprinter.exceptions import (CommandMissingException,
                                  BadCredentialsException,
-                                 ExtractException)
+                                 ExtractException,
+                                 SprinterException)
 
-LOGGER = logging.getLogger('sprinter')
+from core import LOGGER
 
 DOMAIN_REGEX = re.compile("^https?://(\w+\.)?\w+\.\w+\/?")
 COMMAND_WHITELIST = ["cd"]
 BYTE_CHUNKS = 50
 
 
-def get_formula_class(formula, environment):
+def get_subclass_from_module(module, parent_class):
     """
-    Get the formula name and return an instance The formula path is a
-    path to the module. get_formula_class performs reflection to find
-    the first class that extends formulabase, and that is the class
-    that an instance of it gets returned.
+    Get a subclass of parent_class from the module at module
+
+    get_subclass_from_module performs reflection to find the first class that
+    extends the parent_class in the module path, and returns it.
     """
     try:
-        r = __recursive_import(formula)
+        r = __recursive_import(module)
         member_dict = dict(inspect.getmembers(r))
-        sprinter_class = FormulaBase
+        sprinter_class = parent_class
         for v in member_dict.values():
-            if inspect.isclass(v) and issubclass(v, FormulaBase) and v != FormulaBase:
-                if sprinter_class is FormulaBase:
+            if inspect.isclass(v) and issubclass(v, parent_class) and v != parent_class:
+                if sprinter_class is parent_class:
                     sprinter_class = v
         if sprinter_class is None:
-            raise Exception("No formula %s exists in classpath!" % formula)
-        return sprinter_class(environment)
+            raise SprinterException("No subclass %s that extends %s exists in classpath!" % (module, str(parent_class)))
+        return sprinter_class
     except ImportError as e:
         raise e
 
 
-def call(command, stdin=None, env=os.environ, cwd=None, shell=False, output_log_level=logging.INFO, logger=LOGGER):
+def call(command, stdin=None, stdout=PIPE, env=os.environ, cwd=None, shell=False,
+         output_log_level=logging.INFO, logger=LOGGER):
     """ Better, smarter call logic """
     args = command if shell else whitespace_smart_split(command)
-    if not shell and not which(args[0]):
+    kw = {}
+    if not shell and not which(args[0], cwd=cwd):
         raise CommandMissingException(args[0])
-    process = subprocess.Popen(args, stdin=PIPE, stdout=PIPE, stderr=STDOUT,
-                               env=env, cwd=cwd, shell=shell)
+    if shell:
+        kw['shell'] = True
+    process = subprocess.Popen(args, stdin=PIPE, stdout=stdout, stderr=STDOUT,
+                               env=env, cwd=cwd, **kw)
     output = process.communicate(input=stdin)[0]
     logger.log(output_log_level, output)
     return (process.returncode, output)
@@ -197,7 +201,10 @@ def is_affirmative(phrase):
     Determine if a phrase is in the affirmative
     * start with a t or y, case insensitive
     """
-    return phrase.lower()[0] in ['t', 'y']
+    if type(phrase) == str:
+        return phrase.lower()[0] in ['t', 'y']
+    else:
+        return phrase
 
 
 # From:
@@ -206,12 +213,12 @@ def is_exe(fpath):
     return os.path.isfile(fpath) and os.access(fpath, os.X_OK)
 
 
-def which(program):
+def which(program, cwd=None):
     if program in COMMAND_WHITELIST:
         return True
     fpath, fname = os.path.split(program)
     if fpath:
-        if is_exe(program):
+        if is_exe(os.path.join((cwd or os.path.curdir), program)):
             return program
     else:
         for path in os.environ["PATH"].split(os.pathsep):
@@ -318,7 +325,3 @@ def _determine_overwrite(prompt, overwrite, path):
     elif prompt:
         return prompt("Path %s already exist! Overwrite?" % path, boolean=True)
     return True
-
-if __name__ == '__main__':
-    import doctest
-    doctest.testmod()
