@@ -10,13 +10,22 @@ from sprinter.environment import Environment
 from sprinter.manifest import Manifest
 
 
-def create_mock_environment(source_config=None, target_config=None):
+def create_mock_environment(source_config=None, target_config=None,
+                            installed=False):
     """ Create and return a mock environment instance """
     environment = Environment()
     environment.source = (None if not source_config else
                           Manifest(StringIO(source_config), namespace="test"))
     environment.target = (None if not target_config else
                           Manifest(StringIO(target_config), namespace="test"))
+    # mocking directory
+    environment.directory = Mock(spec=environment.directory)
+    environment.directory.bin_path.return_value = "dummy"
+    environment.directory.install_directory.return_value = "/tmp/"
+    environment.directory.new = not installed
+    # mocking injections
+    environment.injections = Mock(spec=environment.injections)
+    environment.write_manifest = Mock()
     return environment
 
 
@@ -27,9 +36,6 @@ class FormulaTest(object):
             source_config=source_config,
             target_config=target_config
         )
-        self.environment.lib = Mock(spec=self.environment.lib)
-        self.environment.directory = Mock(spec=self.environment.directory)
-        self.lib = self.environment.lib
         self.directory = self.environment.directory
-        self.directory.bin_path = Mock(return_value="dummy")
-        self.directory.install_directory = Mock(return_value="/tmp/")
+        self.environment.instantiate_features()
+        self.system = self.environment.system
